#!/bin/bash

#set -e

cur_prog=`basename $0`; cur_dir=`echo $0 | sed "s/${cur_prog}//"`
pushd $cur_dir..
export ABS_PATH=`pwd`
popd

PACK=$1
SIGN_PACK=$2
DEF_KEY=$3

TMP_DIR=/tmp/tmp$$

echo "TMP_DIR=$TMP_DIR"

if [ -z $PACK ] ; then
	echo "Specify pack."
	exit 1
fi

if [ -z $SIGN_PACK ] ; then
	echo "Specify signed pack."
	exit 1
fi

if [ -z $DEF_KEY ] ; then
	echo "Specify key for signed."
	exit 1
fi

package_name=`echo $PACK | awk -F "/" '{print $NF}'`

mkdir -p $TMP_DIR/data
pushd $TMP_DIR
dpkg-deb -x $PACK $TMP_DIR/data
dpkg-deb -e $PACK $TMP_DIR/DEBIAN
popd

if echo $package_name | grep -q "hplip-data"; then
    dpkg --force-yes -i /opt/src-disk/ADDONS/makeself*.deb
    pushd $TMP_DIR/data/usr/share/hplip/data/plugin
    sh ./hplip-3.18.5-plugin.run --target ./plugin_tmp
    popd
fi

IFS=$'\n'

exit_code=0

# Sign files
pushd $TMP_DIR/data
for file in `find . -type f` ; do
	is_it_elf=`readelf -h ${file} 2>&1 > /dev/null; echo $?`
	if [ "${is_it_elf}" == "0" ]; then
		bsign -s --pgoptions "--pinentry-mode=ask --default-key=$DEF_KEY" $file
		exit_code=$?
#		bsign -s -N --pgoptions "--passphrase qwer1234 --default-key=4CF92C19" $file
#		bsign -s -N --pgoptions "--default-key=A00782C8" $file
	fi
done
popd

pushd $TMP_DIR/DEBIAN
for file in `find . -type f` ; do
	is_it_elf=`readelf -h ${file} 2>&1 > /dev/null; echo $?`
	if [ "${is_it_elf}" == "0" ]; then
		bsign -s --pgoptions "--pinentry-mode=ask --default-key=$DEF_KEY" $file
		exit_code=$?
#		bsign -s -N --pgoptions "--default-key=A00782C8" $file
	fi
done

# Counting md5sums
if [ -e ./md5sums ] ; then
	filenames=`cat md5sums | awk -F'  ' '{print $2}'`
	popd
	pushd $TMP_DIR/data
	for j in $filenames
	do
		echo `md5sum $j` >> $TMP_DIR/DEBIAN/md5sums.new
	done
	popd
	mv -f $TMP_DIR/DEBIAN/md5sums.new $TMP_DIR/DEBIAN/md5sums
fi
#popd
if echo $package_name | grep -q "hplip-data"; then

    pushd $TMP_DIR/data/usr/share/hplip/data/plugin
    makeself --gzip ./plugin_tmp/ hplip-3.18.5-plugin.run "HPLIP 3.18.5 Plugin Self Extracting Archive" "./hplip-plugin-install" "-v 3.18.5 -c 42"
    rm -rf plugin_tmp
    popd

fi
# Packing back in deb
pushd $TMP_DIR
mv -f $TMP_DIR/DEBIAN $TMP_DIR/data/
dpkg-deb -b -Zxz $TMP_DIR/data/ $TMP_DIR/$package_name

if [ "$exit_code" -eq "0" ]; then
    mv -f $TMP_DIR/$package_name $SIGN_PACK
fi

popd
rm -rf $TMP_DIR
echo "TMP_DIR=$TMP_DIR"
#rm -f ${PID_DIR_SIGN}/$FREED

if [ "$exit_code" -ne "0" ]; then
    exit 1
fi
